﻿/**
 * @author "Ahmed Abbas <ahmed.abbas@ixd-consultant.com>"
 */
import com.xvisage.utils.StringUtils;
import com.xvisage.ASUnitAS2;
import asunit.framework.TestCase;

class com.xvisage.ASUnitAS2Test extends TestCase {
	private var className:String = "com.xvisage.ASUnitAS2Test";
	private var instance:ASUnitAS2;
	public static var XML_FILE:String; 
	public static var ON_TEAR_DOWN:Function;

	public function ASUnitAS2Test(testMethod:String) {
		super(testMethod);
	}

	public function setUp():Void {
		instance = new ASUnitAS2();
	}

	public function tearDown():Void {
		delete instance;
	}

	public function testInstantiated():Void {
		assertTrue("ASUnitAS2 instantiated", instance instanceof ASUnitAS2);
	}

	public function test():Void {
		var UTILS:StringUtils = new StringUtils();
		UTILS.wrapFactor = .98;
		var xml:XML = new XML();
		xml.ignoreWhite = true;
		xml.onLoad = function(done:Boolean):Void {
			if (done) {

				var textFieldNode:XML;
				var textFormatNode:XML;
				var textNode:XML;
				var assertsNode:XML;
				
				for (var i:Number=0;i < xml.firstChild.childNodes.length; i++) {
					if (xml.firstChild.childNodes[i]["nodeName"] == "textField") {
						textFieldNode = xml.firstChild.childNodes[i];
					} else if (xml.firstChild.childNodes[i]["nodeName"] == "textFormat") {
						textFormatNode = xml.firstChild.childNodes[i];
					} else if (xml.firstChild.childNodes[i]["nodeName"] == "text") {
						textNode = xml.firstChild.childNodes[i];
					} else if (xml.firstChild.childNodes[i]["nodeName"] == "asserts") {
						assertsNode = xml.firstChild.childNodes[i];
					}
				}
				
				if (!textNode) trace("<text> node not found");
				if (!assertsNode) trace("<asserts> node not found");
				
				// create text format
				var textFormat:TextFormat = new TextFormat(
					textFormatNode.attributes["font"] ? textFormatNode.attributes["font"] : "Arial", 
					textFormatNode.attributes["size"] ? textFormatNode.attributes["size"] : 16,
					0x000000, // color
					textFormatNode.attributes["bold"] ? true : false,
					textFormatNode.attributes["italic"] ? true : false,
					textFormatNode.attributes["underline"] ? true : false,
					null, // url
					null, // target
					textFormatNode.attributes["align"] ? textFormatNode.attributes["align"] : "right",
					textFormatNode.attributes["leftMargin"] ? textFormatNode.attributes["leftMargin"] : 0,
					textFormatNode.attributes["rightMargin"] ? textFormatNode.attributes["rightMargin"] : 0,
					textFormatNode.attributes["indent"] ? textFormatNode.attributes["indent"] : 0,
					textFormatNode.attributes["leading"] ? textFormatNode.attributes["leading"] : 0
				);
		
				// create text field
				var width:Number = textFieldNode.attributes["width"] ? textFieldNode.attributes["width"] : Stage.width-10;
				var testField:TextField = _root.createTextField("testField", _root.getNextHighestDepth(), 5, 5, width, 10);
				testField.selectable = textFieldNode.attributes["selectable"] ? textFieldNode.attributes["selectable"] : false;
				testField.antiAliasType = textFieldNode.attributes["antiAliasType"] ? textFieldNode.attributes["antiAliasType"] : "none";
				testField.embedFonts = true;
				testField.wordWrap = true;
				testField.autoSize = true;
				testField.multiline = true;
				testField.html = true;
				testField.text = " "; // initial charachter to be able to apply TextFormat (not required if TextField instance already on-stage)
				testField.setTextFormat(textFormat); // required in order to detect proper format
				
				// use arabic parsing
				testField.htmlText = UTILS.parseArabic(textNode.firstChild.nodeValue, testField);
				testField.setTextFormat(textFormat);
				testField._y = Stage.height-testField._height-5;
				
				// run asserts
				for (i=0; i<assertsNode.childNodes.length; i++) {
					
					var assertNode:XML = assertsNode.childNodes[i];
					var assertStr:String = assertNode.firstChild.nodeValue;
		
					// prepare arabic text
					var arabicText:String = (assertNode.attributes["html"] == "true") ? testField.htmlText : testField.text;
					if (assertNode.attributes["trim"]) {
					    for(var j:Number = 0; arabicText.charCodeAt(j) < 33; i++);
					    for(var k:Number = arabicText.length-1; arabicText.charCodeAt(k) < 33; k--);
					    arabicText = arabicText.substring(j, k+1);
					}
					if (assertNode.attributes["toLowerCase"]) arabicText = arabicText.toLowerCase();
					
					// test ...
					if (assertNode.nodeName === "equal") {
						assertEquals("Test 'equal' failed: '" + arabicText + "' is not equal to '" + assertStr + "'", arabicText, assertStr);
					} else if (assertNode.nodeName === "contains") {
						assertTrue("Test 'contains' failed: '" + arabicText + "' does not contains '" + assertStr + "'", arabicText.indexOf(assertStr) >= 0);
					} else {
						trace("Unknown assert '" + assertNode.nodeName + "'");
					}
			
				}


			}
		};
		xml.load("xml/" + XML_FILE);
	}
}
